{% load i18n %}

<article>
  <header>
    <h2><a href="{{ item.link }}">{{ item.title }}</a></h2>
    <p><a href="{{ item.link }}">{% trans 'Link to the original' %}</a> <a href="{{ item.get_absolute_url }}">Link to the article</a></p>
  </header>
    {% if FEEDAGGREGATOR_SHOW_FULL %}
        {{ item.description|safe }}
    {% else %}
        {{ item.description|safe|truncatewords_html:FEEDAGGREGATOR_EXCERPT_SIZE }}
    {% endif %}
  <footer>
  {% for tag in item.tags.all %}
    <a href="{% url 'feedaggregator:tag_detail' tag.slug %}"><span class="label label-default">{{ tag }}</span></a>
  {% endfor %}
  </footer>
</article>